# -*- coding: utf-8 -*-
import os

API_BASE_URL = os.environ.get('WANGDIANTONG_HOST', 'http://121.41.177.115')

APPSECRET = os.environ.get('WANGDIANTONG_APPSECRET', 'CHANGE-ME')

APPKEY = os.environ.get('WANGDIANTONG_APPKEY', 'CHANGE-ME')

SID = os.environ.get('WANGDIANTONG_SID', 'CHANGE-ME')

SHOP_NO = os.environ.get('WANGDIANTONG_SHOP_NO', 'CHANGE-ME')

PLATFORM_ID = os.environ.get('WANGDIANTONG_PLATFORM_ID', 'CHANGE-ME')

WAREHOUSE_NO = os.environ.get('WANGDIANTONG_WAREHOUSE_NO', 'CHANGE-ME')

